@@ -25,14 +25,39 @@ class SchoolService(BaseService):
     def get_school_buses_locations(self, school_id):
         """
 
-        :param school_id:
+        :param school_id: Identification of a school.
 
-        :return:
+
+        :return: A list of objects containing the following attributes:
+
+* `account_id` (required): Identification of the attendant who is using
+  the tracker device.
+
+* `accuracy` (optional):
+
+* `altitude` (optional):
+
+* `bearing` (optional):
+
+* `fix_time` (required):
+
+* `full_name` (required): Full name by which the attendant is known.
+
+* `latitude` (required):
+
+* `longitude` (required):
+
+* `speed` (optional):
+
+* `team_id` (required): Identification of the team that the attendant
+  belongs to.
+
+* `team_name` (required): Name of the team that the attendant belongs to.
         """
         return Object.from_json(
             self.send_request(
                 http_method=self.HttpMethod.GET,
-                path='/school/(school_id)/tracker/location',
+                path='/school/(school_id)/bus/location',
                 url_bits={
                     'school_id': school_id
                 },
